@@ -266,7 +266,6 @@ static int cq_next_poll(struct ibv_cq_ex *current)
 
 	if (next_index == load_producer_index(q)) {
 		store_consumer_index(cq->queue, cq->cur_index);
-		pthread_spin_unlock(&cq->lock);
 		errno = ENOENT;
 		return errno;
 	}
@@ -1870,7 +1869,7 @@ static struct verbs_context *rxe_alloc_context(struct ibv_device *ibdev,
 		return NULL;
 
 	if (ibv_cmd_get_context(&context->ibv_ctx, &cmd, sizeof(cmd),
-				&resp, sizeof(resp)))
+				NULL, &resp, sizeof(resp)))
 		goto out;
 
 	verbs_set_ops(&context->ibv_ctx, &rxe_ctx_ops);
